@@ -1,26 +1,22 @@
 use strict;
 use warnings;
 package me::inlined;
-# git description: v0.001-13-g2d6093f
-$me::inlined::VERSION = '0.002';
+# git description: v0.002-3-gdf6f913
+$me::inlined::VERSION = '0.003';
 # ABSTRACT: EXPERIMENTAL - define multiple packages in one file, and reference them in any order
 # KEYWORDS: development module package file inline declaration
 # vim: set ts=8 sw=4 tw=78 et :
 
-use Module::Runtime 'module_notional_filename';
+use Module::Runtime ();
 
 sub import
 {
     my $self = shift;
     my ($caller, $caller_file) = caller;
-    my $filename = module_notional_filename($caller);
+    my $filename = Module::Runtime::module_notional_filename($caller);
     $::INC{$filename} = $caller_file;
 }
 
-{
-    no strict 'refs';
-    delete ${ __PACKAGE__ . '::' }{module_notional_filename};
-}
 1;
 
 __END__
@@ -35,7 +31,7 @@ me::inlined - EXPERIMENTAL - define multiple packages in one file, and reference
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -93,7 +89,7 @@ looping when trying to compile modules. Use at your own risk!
 =head1 ACKNOWLEDGEMENTS
 
 This module was inspired by a conversation witnessed on C<modules@perl.org> --
-credit for the idea belongs to Linda Walsh.
+credit for the idea belongs to L<Linda Walsh|https://metacpan.org/author/LAWALSH>.
 
 =head1 SEE ALSO
 
@@ -120,4 +116,10 @@ This software is copyright (c) 2013 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Neil Bowers
+
+Neil Bowers <neil@bowers.com>
+
 =cut
